@@ -17,8 +17,9 @@ $Id: $
 
 from zope.viewlet.viewlet import CSSViewlet
 
-YahooDataTable = CSSViewlet('yui/datatable/assets/datatable.css')
-YahooDataTableSkin = CSSViewlet('yui/assets/skins/sam/datatable.css')
-YahooTreeView = CSSViewlet('yui/assets/skins/sam/treeview.css')
-YahooLogger = CSSViewlet('yui/logger/assets/skins/sam/logger.css')
+YahooDataTable = CSSViewlet('yui/build/datatable/assets/datatable.css')
+YahooDataTableSkin = CSSViewlet('yui/build/assets/skins/sam/datatable.css')
+YahooTreeView = CSSViewlet('yui/build/assets/skins/sam/treeview.css')
+YahooLogger = CSSViewlet('yui/build/logger/assets/skins/sam/logger.css')
+YahooGridCSS = CSSViewlet('yui/build/reset-fonts-grids/reset-fonts-grids.css')
 
