@@ -17,8 +17,10 @@ YahooBase = JavaScriptViewlet('yui/yahoo/yahoo.js')
 YahooEvent = JavaScriptViewlet('yui/event/event.js')
 YahooConnection = JavaScriptViewlet('yui/connection/connection.js')
 YahooDom = JavaScriptViewlet('yui/dom/dom.js')
+YahooCore = JavaScriptViewlet('yui/build/yahoo-dom-event/yahoo-dom-event.js')
 YahooLogger = JavaScriptViewlet('yui/logger/logger-min.js')
 YahooElement = JavaScriptViewlet('yui/element/element-beta.js')
 YahooDataSource = JavaScriptViewlet('yui/datasource/datasource-beta.js')
 YahooDataTable = JavaScriptViewlet('yui/datatable/datatable-beta.js')
 YahooTree = JavaScriptViewlet('yui/treeview/treeview.js')
+YahooSelector = JavaScriptViewlet('yui/selector/selector.js')
